=== modified file 'tests.py'
--- tests.py	2006-02-12 03:47:20 +0000
+++ tests.py	2006-02-21 04:42:50 +0000
@@ -3,7 +3,7 @@
 import bzrlib.tests
 import os.path
 
-class ShelfTests(bzrlib.tests.TestCaseInTempDir):
+class ShelfTests(bzrlib.tests.TestCaseWithTransport):
     ORIGINAL = '\n\nhello test world\n\n'
     MODIFIED = '\n\ngoodbye test world\n\n'
     DIFF_HEADER = "=== modified file 'test_file'\n"
@@ -32,13 +32,8 @@
         self.__test_loop(10)
 
     def __test_loop(self, count):
-        from bzrlib.branch import Branch
-        b = Branch.initialize('.')
-
-        # Create a test file and commit it
-        file('test_file', 'w').write(self.ORIGINAL)
-        b.working_tree().add('test_file')
-        b.working_tree().commit(message='add test_file')
+        tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file(tree)
 
         while count > 0:
             count -= 1
@@ -60,7 +55,8 @@
             self.assertEqual(file('test_file').read(), self.ORIGINAL)
 
             # Check the shelf is right
-            shelf = open(os.path.join(b.base, '.shelf/shelves/default/00')).read()
+            shelf = open(os.path.join(tree.branch.base,
+                        '.shelf/shelves/default/00')).read()
             shelf = shelf[shelf.index('\n') + 1:] # skip the message
             self.assertEqual(shelf, self.DIFF_1)
 
@@ -76,32 +72,29 @@
 
     def test_shelf_nothing_to_shelve(self):
         import os.path
-        from bzrlib.branch import Branch
-        b = Branch.initialize('.')
-
-        # Create a test file and commit it
-        file('test_file', 'w').write(self.ORIGINAL)
-        b.working_tree().add('test_file')
-        b.working_tree().commit(message='add test_file')
+        tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file(tree)
 
         # Shelve the changes
         self.run_bzr('shelve', retcode=3)
 
-        if os.path.exists(os.path.join(b.base, '.shelf/shelves/default/00')):
+        if os.path.exists(os.path.join(tree.branch.base,
+                '.shelf/shelves/default/00')):
             self.fail("Shelf exists, but it shouldn't")
 
+    def __create_and_add_test_file(self, tree):
+        self.build_tree_contents([('test_file', self.ORIGINAL)])
+        tree.add('test_file')
+        tree.commit(message='add test_file')
+
     def test_shelf_with_revision(self):
-        from bzrlib.branch import Branch
-        b = Branch.initialize('.')
+        tree = self.make_branch_and_tree('.')
 
-        # Create a test file and commit it
-        file('test_file', 'w').write(self.ORIGINAL)
-        b.working_tree().add('test_file')
-        b.working_tree().commit(message='add test_file')
+        self.__create_and_add_test_file(tree)
 
         # Modify the test file and commit it
-        file('test_file', 'w').write(self.MODIFIED)
-        b.working_tree().commit(message='update test_file')
+        self.build_tree_contents([('test_file', self.MODIFIED)])
+        tree.commit(message='update test_file')
 
         # Shelve the changes
         self.run_bzr('shelve', '-r', '1', retcode=0)
@@ -120,8 +113,7 @@
         self.assertEqual(file('test_file').read(), self.MODIFIED)
 
     def test_shelf_with_two_revisions(self):
-        from bzrlib.branch import Branch
-        b = Branch.initialize('.')
+        tree = self.make_branch_and_tree('.')
 
         cmd = 'shelve -r 1..2'
         (stdout, stderr) = self.run_bzr_captured(cmd.split(), retcode=None)

